@@ -7,54 +7,44 @@ Log::Handler::Output::DBI - Log messages to a database.
     use Log::Handler::Output::DBI;
 
     my $db = Log::Handler::Output::DBI->new(
-        # database source
-        database    => "database",
-        driver      => "mysql",
-        host        => "127.0.0.1",
-        port        => 3306,
-
-        # or with "dbname" instead of "database"
-        dbname      => "database",
-        driver      => "Pg",
-        host        => "127.0.0.1",
-        port        => 5432,
-
-        # or with data_source
-        data_source => "dbi:mysql:database=database;host=127.0.0.1;port=3306",
-
-        # Username and password
-        user        => "user",
-        password    => "password",
+        # database connection
+        database   => 'database',
+        driver     => 'mysql',
+        user       => 'user',
+        password   => 'password',
+        host       => '127.0.0.1',
+        port       => 3306,
 
         # debugging
-        debug       => 1,
+        debug      => 1,
 
         # table, columns and values (as string)
-        table       => "messages",
-        columns     => "level ctime cdate pid hostname progname message",
-        values      => "%level %time %date %pid %hostname %progname %message",
+        table      => 'messages',
+        columns    => 'level ctime cdate pid hostname progname message',
+        values     => '%level %time %date %pid %hostname %progname %message',
 
         # table, columns and values (as array reference)
-        table       => "messages",
-        columns     => [ qw/level ctime cdate pid hostname progname message/ ],
-        values      => [ qw/%level %time %date %pid %hostname %progname %message/ ],
+        table      => 'messages',
+        columns    => [ qw/level ctime cdate pid hostname progname message/ ],
+        values     => [ qw/%level %time %date %pid %hostname %progname %message/ ],
 
         # table, columns and values (your own statement)
-        statement   => "insert into messages (level,ctime,cdate,pid,hostname,progname,message) values (?,?,?,?,?,?,?)",
-        values      => [ qw/%level %time %date %pid %hostname %progname %message/ ],
+        statement  => 'insert into messages (level,ctime,cdate,pid,hostname,progname,message) values (?,?,?,?,?,?,?)',
+        values     => [ qw/%level %time %date %pid %hostname %progname %message/ ],
 
         # if you like persistent connections and want to re-connect
-        persistent  => 1,
+        persistent => 1,
+        reconnect  => 1,
     );
 
     my %message = (
-        level       => "ERROR",
-        time        => "10:12:13",
-        date        => "1999-12-12",
+        level       => 'ERROR',
+        time        => '10:12:13',
+        date        => '1999-12-12',
         pid         => $$,
-        hostname    => "localhost",
+        hostname    => 'localhost',
         progname    => $0,
-        message     => "an error here"
+        message     => 'an error here'
     );
 
     $db->log(\%message);
@@ -73,14 +63,7 @@ The following options are possible:
 
 =over 4
 
-=item B<data_source>
-
-Set the dsn (data source name).
-
-You can use this parameter instead of C<database>, C<driver>, C<host>
-and C<port>.
-
-=item B<database> or B<dbname>
+=item B<database>
 
 Pass the database name.
 
@@ -88,14 +71,6 @@ Pass the database name.
 
 Pass the database driver.
 
-=item B<host>
-
-Pass the hostname where the database is running.
-
-=item B<port>
-
-Pass the port where the database is listened.
-
 =item B<user>
 
 Pass the database user for the connect.
@@ -104,16 +79,24 @@ Pass the database user for the connect.
 
 Pass the users password.
 
+=item B<host>
+
+Pass the hostname where the database is running.
+
+=item B<port>
+
+Pass the port where the database is listened.
+
 =item B<table> and B<columns>
 
 With this options you can pass the table name for the insert and the columns.
 You can pass the columns as string or as array. Example:
 
     # the table name
-    table => "messages",
+    table => 'messages',
 
     # columns as string
-    columns => "level, ctime, cdate, pid, hostname, progname, message",
+    columns => 'level, ctime, cdate, pid, hostname, progname, message',
 
     # columns as array
     columns => [ qw/level ctime cdate pid hostname progname message/ ],
@@ -128,21 +111,21 @@ The statement would created as follows
 With this option you can pass your own statement if you don't want to you the
 options C<table> and C<columns>.
 
-    statement => "insert into message (level, ctime, cdate, pid, hostname, progname, mtime, message)"
-                 ." values (?,?,?,?,?,?,?)"
+    statement => 'insert into message (level, ctime, cdate, pid, hostname, progname, mtime, message)'
+                 .' values (?,?,?,?,?,?,?)'
 
 =item B<values>
 
 With this option you have to set the values for the insert.
 
-        values => "%level, %time, %date, %pid, %hostname, %progname, %message",
+        values => '%level, %time, %date, %pid, %hostname, %progname, %message',
 
         # or
 
         values => [ qw/%level %time %date %pid %hostname %progname %message/ ],
 
 The placeholders are identical with the pattern names that you have to pass
-with the option C<message_pattern> from L<Log::Handler>.
+with the option C<message_pattern>.
 
     %L   level
     %T   time
@@ -150,24 +133,27 @@ with the option C<message_pattern> from L<Log::Handler>.
     %P   pid
     %H   hostname
     %N   newline
+    %R   runtime
     %C   caller
     %p   package
     %f   filename
     %l   line
     %s   subroutine
     %S   progname
-    %r   runtime
     %t   mtime
     %m   message
 
 Take a look to the documentation of L<Log::Handler> for all possible patterns.
 
-=item B<persistent>
+=item B<persistent> and B<reconnect>
 
 With this option you can enable or disable a persistent database connection and
 re-connect if the connection was lost.
 
-This option is set to 1 on default.
+If you use persistent connections then a ping is send to the database before
+each insert. If the ping fails then a re-connect is executed.
+
+Both options are set to 1 on default.
 
 =item B<dbi_params>
 
@@ -188,7 +174,7 @@ You can pass your own arguments - and overwrite it - with
 
 =item B<debug>
 
-With this option it's possible to enable debugging. The information can be
+With this option it's possible to enable debugging. The informations can be
 intercepted with C<$SIG{__WARN__}>.
 
 =back
@@ -198,36 +184,23 @@ intercepted with C<$SIG{__WARN__}>.
 Log a message to the database.
 
     my $db = Log::Handler::Output::DBI->new(
-        database   => "database",
-        driver     => "mysql",
-        user       => "user",
-        password   => "password",
-        host       => "127.0.0.1",
+        database   => 'database',
+        driver     => 'mysql',
+        user       => 'user',
+        password   => 'password',
+        host       => '127.0.0.1',
         port       => 3306,
-        table      => "messages",
+        table      => 'messages',
         columns    => [ qw/level ctime message/ ],
         values     => [ qw/%level %time %message/ ],
         persistent => 1,
+        reconnect  => 1,
     );
 
     $db->log(
-        message => "your message",
-        level   => "INFO",
-        time    => "2008-10-10 10:12:23",
-    );
-
-Or you can connect to the database yourself. You should
-notice that if the database connection lost then the
-logger can't re-connect to the database and would return
-an error. You C<dbi_handle> at your own risk.
-
-    my $dbh = DBI->connect(...);
-
-    my $db = Log::Handler::Output::DBI->new(
-        dbi_handle => $dbh,
-        table      => "messages",
-        columns    => [ qw/level ctime message/ ],
-        values     => [ qw/%level %time %message/ ],
+        message => 'your message',
+        level   => 'INFO',
+        time    => '2008-10-10 10:12:23',
     );
 
 =head2 connect()
@@ -238,14 +211,6 @@ Connect to the database.
 
 Disconnect from the database.
 
-=head2 validate()
-
-Validate a configuration.
-
-=head2 reload()
-
-Reload with a new configuration.
-
 =head2 errstr()
 
 This function returns the last error message.
@@ -273,7 +238,7 @@ Jonny Schulz <jschulz.cpan(at)bloonix.de>.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2007-2009 by Jonny Schulz. All rights reserved.
+Copyright (C) 2007 by Jonny Schulz. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
@@ -284,20 +249,23 @@ package Log::Handler::Output::DBI;
 
 use strict;
 use warnings;
-use DBI;
 use Carp;
-use Params::Validate qw();
+use DBI;
+use Params::Validate;
 
-our $VERSION = "0.11";
-our $ERRSTR  = "";
+our $VERSION = '0.01';
+our $ERRSTR  = '';
 
 sub new {
-    my $class = shift;
-    my $opts  = $class->_validate(@_);
-    my $self  = bless $opts, $class;
+    my $class   = shift;
+    my $options = $class->_validate(@_);
+    my $self    = bless $options, $class;
 
-    if ($self->{debug}) {
-        warn "Create a new Log::Handler::Output::DBI object";
+    warn "Create a new Log::Handler::Output::DBI object" if $self->{debug};
+
+    if ($self->{persistent}) {
+        warn "Peristent connections is set to true" if $self->{debug};
+        $self->connect or return undef;
     }
 
     return $self;
@@ -306,29 +274,42 @@ sub new {
 sub log {
     my $self    = shift;
     my $message = @_ > 1 ? {@_} : shift;
-    my @values  = ();
+
+    if ($self->{persistent}) {
+        warn "ping the database" if $self->{debug};
+        if (!$self->{dbh}->ping) {
+            $self->connect or return undef;
+        }
+    } else {
+        $self->connect or return undef;
+    }
+
+    warn "prepare: $self->{statement}" if $self->{debug};
+
+    my $sth = $self->{dbh}->prepare($self->{statement})
+        or return $self->_raise_error("DBI prepare error: ".$self->{dbh}->errstr);
+
+    my @values;
 
     foreach my $v (@{$self->{values}}) {
-        if (ref($v) eq "CODE") {
+        if (ref($v) eq 'CODE') {
             push @values, &$v();
-        } elsif ($v =~ /^%(.+)/ && exists $message->{$1}) {
+        } elsif ($v =~ /^%(.+)/) {
             push @values, $message->{$1};
         } else {
             push @values, $v;
         }
     }
 
-    if ($self->{debug}) {
-        warn "execute: ".@values." bind values";
-    }
+    warn "execute: ".@values." bind values" if $self->{debug};
 
-    $self->connect or return undef;
+    $sth->execute(@values)
+        or return $self->_raise_error("DBI execute error: ".$sth->errstr);
 
-    if ( ! $self->{sth}->execute(@values) ) {
-        return $self->_raise_error("DBI execute error: ".DBI->errstr);
-    }
+    $sth->finish
+        or return $self->_raise_error("DBI finish error: ".$sth->errstr);
 
-    if (!$self->{persistent} && !$self->{dbi_handle}) {
+    if (!$self->{persistent}) {
         $self->disconnect or return undef;
     }
 
@@ -338,101 +319,26 @@ sub log {
 sub connect {
     my $self = shift;
 
-    if ($self->{persistent} && $self->{dbh}) {
-        if ($self->{use_ping}) {
-            if ($self->{dbh}->ping) {
-                return 1;
-            }
-        } else {
-            eval { $self->{dbh}->do($self->{pingstmt}) or die DBI->errstr };
-            return 1 unless $@;
-        }
-    }
+    warn "Connect to the database: $self->{cstr}->[0] ..." if $self->{debug};
 
-    if ($self->{debug}) {
-        warn "Connect to the database: $self->{cstr}->[0] ...";
-    }
-
-    my $dbh;
-
-    if ($self->{dbi_handle}) {
-        # If db ping failed and dbi_handle and dbi is set
-        # then it seems that the database is down.
-        if ($self->{dbi}) {
-            return $self->_raise_error("dbi_handle - lost connection");
-        }
-        $dbh = $self->{dbi_handle};
-    } else {
-        $dbh = DBI->connect(@{$self->{cstr}})
-            or return $self->_raise_error("DBI connect error: ".DBI->errstr);
-    }
-
-    my $sth = $dbh->prepare($self->{statement})
-        or return $self->_raise_error("DBI prepare error: ".$dbh->errstr);
+    my $dbh = DBI->connect(@{$self->{cstr}})
+        or return $self->_raise_error("DBI connect error: ".DBI->errstr);
 
     $self->{dbh} = $dbh;
-    $self->{sth} = $sth;
 
     return 1;
 }
 
 sub disconnect {
     my $self = shift;
-
-    if ($self->{sth}) {
-        $self->{sth}->finish
-            or return $self->_raise_error("DBI finish error: ".$self->{sth}->errstr);
-
-        delete $self->{sth};
-    }
-
-    if ($self->{dbh}) {
-        if ($self->{debug}) {
-            warn "Disconnect from database";
-        }
-
-        $self->{dbh}->disconnect
-            or return $self->_raise_error("DBI disconnect error: ".DBI->errstr);;
-
-        delete $self->{dbh};
-    }
-
+    warn "Disconnect from database" if $self->{debug};
+    $self->{dbh}->disconnect
+        or return $self->_raise_error("DBI disconnect error: ".DBI->errstr);;
+    delete $self->{dbh};
     return 1;
 }
 
-sub validate {
-    my $self = shift;
-    my $opts = ();
-
-    eval { $opts = $self->_validate(@_) };
-
-    if ($@) {
-        return $self->_raise_error($@);
-    }
-
-    return $opts;
-}
-
-sub reload {
-    my $self = shift;
-    my $opts = $self->validate(@_);
-
-    if (!$opts) {
-        return undef;
-    }
-
-    $self->disconnect;
-
-    foreach my $key (keys %$opts) {
-        $self->{$key} = $opts->{$key};
-    }
-
-    return 1;
-}
-
-sub errstr {
-    return $ERRSTR;
-}
+sub errstr { $ERRSTR }
 
 #
 # private stuff
@@ -442,21 +348,11 @@ sub _validate {
     my $class = shift;
 
     my %options = Params::Validate::validate(@_, {
-        data_source => {
-            type => Params::Validate::SCALAR,
-            optional => 1,
-        },
         database => {
             type => Params::Validate::SCALAR,
-            optional => 1,
-        },
-        dbname => {
-            type => Params::Validate::SCALAR,
-            optional => 1,
         },
         driver => {
             type => Params::Validate::SCALAR,
-            optional => 1,
         },
         user => {
             type => Params::Validate::SCALAR,
@@ -464,11 +360,12 @@ sub _validate {
         },
         password => {
             type => Params::Validate::SCALAR,
-            optional => 1,
+            depends => [ 'user' ],
         },
         host => {
             type => Params::Validate::SCALAR,
             optional => 1,
+            depends => [ 'port' ],
         },
         port => {
             type => Params::Validate::SCALAR,
@@ -476,12 +373,12 @@ sub _validate {
         },
         table => {
             type => Params::Validate::SCALAR,
-            depends => [ "columns" ],
+            depends => [ 'columns' ],
             optional => 1,
         },
         columns => {
             type => Params::Validate::SCALAR | Params::Validate::ARRAYREF,
-            depends => [ "table" ],
+            depends => [ 'table' ],
             optional => 1,
         },
         values => {
@@ -491,6 +388,10 @@ sub _validate {
             type => Params::Validate::SCALAR,
             optional => 1,
         },
+        reconnect => {
+            type => Params::Validate::SCALAR,
+            default => 1,
+        },
         persistent => {
             type => Params::Validate::SCALAR,
             default => 1,
@@ -499,11 +400,6 @@ sub _validate {
             type => Params::Validate::HASHREF,
             default => { PrintError => 0, AutoCommit => 1 },
         },
-        use_ping => {
-            type => Params::Validate::SCALAR,
-            regex => qr/^[01]\z/,
-            default => 0,
-        },
         debug => {
             type => Params::Validate::SCALAR,
             regex => qr/^[01]\z/,
@@ -515,33 +411,19 @@ sub _validate {
         Carp::croak "Missing one of the mandatory options: 'statement' or 'table' and 'columns'";
     }
 
-    # build the connect string (data source name)
-    my @cstr = ();
+    # build the connect string
+    my @cstr = ("dbi:$options{driver}:database=$options{database}");
 
-    if (defined $options{data_source}) {
-        @cstr = ($options{data_source});
-    } elsif ($options{driver} && ($options{database} || $options{dbname})) {
-        $cstr[0] = "dbi:$options{driver}:";
-
-        if ($options{database}) {
-            $cstr[0] .= "database=$options{database}";
-        } else {
-            $cstr[0] .= "dbname=$options{dbname}";
+    if ($options{host}) {
+        $cstr[0] .= ";host=$options{host}";
+        if ($options{port}) {
+            $cstr[0] .= ";port=$options{port}";
         }
-
-        if ($options{host}) {
-            $cstr[0] .= ";host=$options{host}";
-            if ($options{port}) {
-                $cstr[0] .= ";port=$options{port}";
-            }
-        }
-    } else {
-        Carp::croak "Missing mandatory options data_source or database/dbname";
     }
 
     if ($options{user}) {
         $cstr[1] = $options{user};
-        if ($options{password}) {
+        if ($options{port}) {
             $cstr[2] = $options{password};
         }
     }
@@ -560,28 +442,22 @@ sub _validate {
         $options{statement} = "insert into $options{table} (";
 
         if (ref($options{columns})) {
-            $options{statement} .= join(",", @{$options{columns}});
+            $options{statement} .= join(',', @{$options{columns}});
         } else {
-            $options{statement} .= join(",", split /[\s,]+/, $options{columns});
+            $options{statement} .= join(',', split /[\s,]+/, $options{columns});
         }
 
-        $options{statement} .= ") values (";
+        $options{statement} .= ') values (';
 
         my @binds;
         foreach my $v (@{$options{values}}) {
             $v =~ s/^\s+//;
             $v =~ s/\s+\z//;
-            push @binds, "?";
+            push @binds, '?';
         }
 
-        $options{statement} .= join(",", @binds);
-        $options{statement} .= ")";
-    }
-
-    if ($options{driver} && $options{driver} =~ /oracle/i) {
-        $options{pingstmt} = "select 1 from dual";
-    } else {
-        $options{pingstmt} = "select 1";
+        $options{statement} .= join(',', @binds);
+        $options{statement} .= ')';
     }
 
     return \%options;
