@@ -7,7 +7,7 @@ Log::Handler::Output::Screen - Log messages to the screen.
     use Log::Handler::Output::Screen;
 
     my $screen = Log::Handler::Output::Screen->new(
-        log_to => "STDERR",
+        log_to => 'STDERR',
         dump   => 1,
     );
 
@@ -29,9 +29,7 @@ The following options are possible:
 
 =item B<log_to>
 
-Where do you want to log? Possible is: STDOUT, STDERR and WARN.
-
-WARN means to call C<warn()>.
+Where do you want to log? Possible is: STDOUT and STDERR.
 
 The default is STDOUT.
 
@@ -48,15 +46,7 @@ Call C<log()> if you want to log a message to the screen.
 
 Example:
 
-    $screen->log("this message goes to the screen");
-
-=head2 validate()
-
-Validate a configuration.
-
-=head2 reload()
-
-Reload with a new configuration.
+    $screen->log('this message goes to the screen');
 
 =head2 errstr()
 
@@ -64,6 +54,7 @@ This function returns the last error message.
 
 =head1 PREREQUISITES
 
+    Carp
     Data::Dumper
     Params::Validate
 
@@ -83,7 +74,7 @@ Jonny Schulz <jschulz.cpan(at)bloonix.de>.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2007-2010 by Jonny Schulz. All rights reserved.
+Copyright (C) 2007 by Jonny Schulz. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
@@ -95,10 +86,10 @@ package Log::Handler::Output::Screen;
 use strict;
 use warnings;
 use Data::Dumper;
-use Params::Validate qw();
+use Params::Validate;
 
-our $VERSION = "0.06";
-our $ERRSTR  = "";
+our $VERSION  = '0.01';
+our $ERRSTR   = '';
 
 sub new {
     my $class   = shift;
@@ -109,57 +100,23 @@ sub new {
 sub log {
     my $self    = shift;
     my $message = @_ > 1 ? {@_} : shift;
-    local $|=1;
 
     if ($self->{dump}) {
         $message->{message} = Dumper($message);
     }
 
-    if ($self->{log_to} eq "STDOUT") {
+    if ($self->{log_to} eq 'STDOUT') {
         print STDOUT $message->{message}
             or return $self->_raise_error($!);
-    } elsif ($self->{log_to} eq "STDERR") {
+    } else {
         print STDERR $message->{message}
             or return $self->_raise_error($!);
-    } elsif ($self->{log_to} eq "WARN") {
-        warn $message->{message};
     }
 
     return 1;
 }
 
-sub validate {
-    my $self = shift;
-    my $opts = ();
-
-    eval { $opts = $self->_validate(@_) };
-
-    if ($@) {
-        $ERRSTR = $@;
-        return undef;
-    }
-
-    return $opts;
-}
-
-sub reload {
-    my $self = shift;
-    my $opts = $self->validate(@_);
-
-    if (!$opts) {
-        return undef;
-    }
-
-    foreach my $key (keys %$opts) {
-        $self->{$key} = $opts->{$key};
-    }
-
-    return 1;
-}
-
-sub errstr {
-    return $ERRSTR;
-}
+sub errstr { $ERRSTR }
 
 #
 # private stuff
@@ -171,39 +128,17 @@ sub _validate {
     my %options = Params::Validate::validate(@_, {
         log_to => {
             type => Params::Validate::SCALAR,
-            regex => qr/^(?:STDOUT|STDERR|WARN)\z/,
-            default => "STDOUT",
+            regex => qr/^STD(?:ERR|OUT)\z/,
+            default => 'STDOUT',
         },
         dump => {
             type => Params::Validate::SCALAR,
             regex => qr/^[01]\z/,
             default => 0,
         },
-        utf8 => {
-            type => Params::Validate::SCALAR,
-            regex => qr/^[01]\z/,
-            default => 0,
-        },
     });
 
-    if ($options{log_to} eq "STDOUT") {
-        $options{fh} = \*STDOUT;
-    } elsif ($options{log_to} eq "STDERR") {
-        $options{fh} = \*STDERR;
-    }
-
-    if ($options{fh} && $options{utf8}) {
-        my $fh = $options{fh};
-        binmode $fh, ':utf8';
-    }
-
     return \%options;
 }
 
-sub _raise_error {
-    my $self = shift;
-    $ERRSTR = shift;
-    return undef;
-}
-
 1;
