@@ -1,12 +1,12 @@
 =head1 NAME
 
-Log::Handler::Plugin::YAML - Config loader for YAML.
+Log::Handler::Plugin::Config::YAML - Config loader for YAML.
 
 =head1 SYNOPSIS
 
-    use Log::Handler::Plugin::YAML;
+    use Log::Handler::Plugin::Config::YAML;
 
-    my $config = Log::Handler::Plugin::YAML->get_config( $config_file );
+    my $config = Log::Handler::Plugin::Config::YAML->get_config( $config_file );
 
 =head1 ROUTINES
 
@@ -27,9 +27,9 @@ Expect the config file name and returns the config as a reference.
         mode: append
         newline: 1
         permissions: 0640
-        message_layout: %T %H[%P] [%L] %S: %m
+        prefix: '%T %H[%P] [%L] %S: '
         reopen: 1
-        timeformat: %b %d %H:%M:%S
+        timeformat: '%b %d %H:%M:%S'
 
 =head1 PREREQUISITES
     
@@ -51,20 +51,20 @@ Jonny Schulz <jschulz.cpan(at)bloonix.de>.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2007-2010 by Jonny Schulz. All rights reserved.
+Copyright (C) 2007 by Jonny Schulz. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
 =cut
 
-package Log::Handler::Plugin::YAML;
+package Log::Handler::Plugin::Config::YAML;
 
 use strict;
 use warnings;
 use YAML;
 
-our $VERSION = '0.03';
+our $VERSION = '0.01';
 
 sub get_config {
     my ($class, $config_file) = @_;
